# -*- coding: utf-8 -*-
# Generated by Django 1.11.3 on 2017-07-12 10:45
from __future__ import unicode_literals

from django.db import migrations, models
import heavy_celery.storage


class Migration(migrations.Migration):

    dependencies = [
        ('heavy_celery', '0003_celerytasklog'),
    ]

    operations = [
        migrations.AlterField(
            model_name='celerytask',
            name='result_file',
            field=models.FileField(blank=True, null=True, storage=heavy_celery.storage.CeleryTaskFileStorage(), upload_to=b'', verbose_name='\u7d50\u679c\u30d5\u30a1\u30a4\u30eb'),
        ),
    ]
