# -*- coding: utf-8 -*-
# Generated by Django 1.11.3 on 2017-07-12 03:00
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('heavy_celery', '0002_worker_workertasklog'),
    ]

    operations = [
        migrations.CreateModel(
            name='CeleryTaskLog',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True)),
                ('updated_at', models.DateTimeField(auto_now=True)),
                ('level', models.IntegerField(choices=[(0, 'debug'), (1, 'info'), (2, 'warning'), (3, 'error'), (4, 'critical'), (5, 'exception')])),
                ('text', models.TextField()),
                ('task', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='heavy_celery.CeleryTask')),
            ],
        ),
    ]
